package com.shiyanlou.dao.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.Data;
import lombok.ToString;

import javax.persistence.*;
import java.util.List;
import java.util.Set;

/**
 * @ClassName Resource
 * @Description 权限实体
 * @Modify ...
 */
@Entity
@Table(name = "t_resource")
@Data
@ToString
public class Resource {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    //权限名称
    @Column(nullable = false, length = 20)
    private String name;

    //实际需要控制权限的url
    @ElementCollection(fetch = FetchType.EAGER)
    private Set<String> urls;

    //描述
    private String description;

    //父节点
    @ManyToOne(cascade = CascadeType.MERGE)
    @JoinColumn(name = "pid")
    @JsonIgnore
    private Resource parent;

    //子节点
    @OneToMany(mappedBy = "parent", cascade = CascadeType.REMOVE, fetch = FetchType.LAZY)
    @OrderBy("id ASC")
    @JsonIgnore
    private List<Resource> children;

    public Resource() {
    }

    public Resource(String name, Resource parent, Set<String> urls) {
        this.name = name;
        this.parent = parent;
        this.urls = urls;
    }

}
