package com.shiyanlou.core.authorize;

import org.springframework.core.annotation.Order;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configurers.ExpressionUrlAuthorizationConfigurer;
import org.springframework.stereotype.Component;

/**
 * @ClassName ShiyanlouAuthorizeConfigProvider
 * @Description 核心模块的授权配置提供器，安全模块涉及的url的授权配置在这里。
 * @Modify ...
 */
@Component
@Order(Integer.MIN_VALUE)
public class ShiyanlouAuthorizeConfigProvider implements AuthorizeConfigProvider{
    @Override
    public boolean config(ExpressionUrlAuthorizationConfigurer<HttpSecurity>.ExpressionInterceptUrlRegistry config) {

        config.antMatchers(
                "/authentication/*",
                "/code/*",
                "/oauth/*",
                "/error/*",
                "/h2-console/**"
        ).permitAll();
//        .antMatchers(
//                "/u/me"
//        ).hasRole("ADMIN");

        // 允许来自同一来源的 H2 控制台的请求
        try {
            config.and().headers().frameOptions().sameOrigin();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }
}
