package com.shiyanlou.core.token.server;

import com.shiyanlou.core.authentication.ShiyanlouAuthenticationFailureHandler;
import com.shiyanlou.core.authentication.ShiyanlouAuthenticationSuccessHandler;
import com.shiyanlou.core.authentication.mobile.SmsCodeAuthenticationSecurityConfig;
import com.shiyanlou.core.authorize.AuthorizeConfigManager;
import com.shiyanlou.core.properties.SecurityProperties;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.oauth2.config.annotation.web.configuration.EnableResourceServer;
import org.springframework.security.oauth2.config.annotation.web.configuration.ResourceServerConfigurerAdapter;
import org.springframework.security.oauth2.config.annotation.web.configurers.ResourceServerSecurityConfigurer;
import org.springframework.security.oauth2.provider.expression.OAuth2WebSecurityExpressionHandler;

/**
 * @ClassName ShiyanlouResourceServerConfig
 * @Description 资源服务器
 * @Modify ...
 */
@Configuration
@EnableResourceServer
public class ShiyanlouResourceServerConfig extends ResourceServerConfigurerAdapter {


    @Autowired
    private OAuth2WebSecurityExpressionHandler expressionHandler;

    @Autowired
    private ShiyanlouAuthenticationSuccessHandler authenticationSuccessHandler;
    @Autowired
    private ShiyanlouAuthenticationFailureHandler authenticationFailureHandler;

    @Autowired
    private SecurityProperties securityProperties;

    @Autowired
    private SmsCodeAuthenticationSecurityConfig smsCodeAuthenticationSecurityConfigs;

    @Autowired
    private AuthorizeConfigManager authorizeConfigManager;

    @Override
    public void configure(HttpSecurity http) throws Exception {
        // 配置表单登录
        http.formLogin()
                .loginPage(securityProperties.getAuthenticationUrl())
                .loginProcessingUrl(securityProperties.getLoginProcessingUrl())
                .successHandler(authenticationSuccessHandler)
                .failureHandler(authenticationFailureHandler);

        http
                // 应用短信验证码登录配置
                .apply(smsCodeAuthenticationSecurityConfigs)
//                .and()
//                    // 要放行的路径
//                    .authorizeRequests()
//                    .antMatchers(
//                            "/authentication/*",
//                            "/code/*",
//                            "/oauth/*",
//                            "/error/*"
//                    ).permitAll()
//                    // 对别的任意请求都必须是已认证才能访问
//                    .anyRequest().authenticated()
                .and()
                    .csrf().disable();

        // 资源配置
        authorizeConfigManager.config(http.authorizeRequests());
    }

    @Override
    public void configure(ResourceServerSecurityConfigurer resources) throws Exception {
        resources.expressionHandler(expressionHandler);
    }


    @Bean
    public OAuth2WebSecurityExpressionHandler oAuth2WebSecurityExpressionHandler(ApplicationContext applicationContext) {

        OAuth2WebSecurityExpressionHandler expressionHandler = new OAuth2WebSecurityExpressionHandler();

        expressionHandler.setApplicationContext(applicationContext);

        return expressionHandler;

    }
}
