package com.shiyanlou.core.validate;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.ServletWebRequest;

import java.util.concurrent.TimeUnit;

/**
 * @ClassName RedisValidateCodeRepository
 * @Description redis 储存方式
 * @Modify ...
 */
@Component
public class RedisValidateCodeRepository implements ValidateCodeRepository{

    @Autowired
    private RedisTemplate<Object, Object> redisTemplate;

    @Override
    public void save(ServletWebRequest request, SmsCode code) {
        redisTemplate.opsForValue().set(buildKey(request), code, 30, TimeUnit.MINUTES);
    }

    @Override
    public SmsCode get(ServletWebRequest request) {

        Object value = redisTemplate.opsForValue().get(buildKey(request));

        if (value == null) {
            return null;
        }

        return (SmsCode) value;
    }

    @Override
    public void remove(ServletWebRequest request) {
        redisTemplate.delete(buildKey(request));
    }

    private String buildKey(ServletWebRequest request) {

        String deviceId = request.getParameter("deviceId");//获取设备Id【token也可能会刷新】
        if (StringUtils.isBlank(deviceId)) {
            throw new ValidateCodeException("请在请求中携带deviceId参数");
        }
        return "code:smscode:" + deviceId;
    }
}

